
# This is a fix for InnoDB in MySQL >= 4.1.x
# It "suspends judgement" for fkey relationships until are tables are set.
SET FOREIGN_KEY_CHECKS = 0;

#-----------------------------------------------------------------------------
#-- unit_type
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit_type`;


CREATE TABLE `unit_type`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`global_description` VARCHAR(250),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- unit_type_i18n
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit_type_i18n`;


CREATE TABLE `unit_type_i18n`
(
	`id` INTEGER  NOT NULL,
	`culture` VARCHAR(7)  NOT NULL,
	`description` VARCHAR(250),
	PRIMARY KEY (`id`,`culture`),
	CONSTRAINT `unit_type_i18n_FK_1`
		FOREIGN KEY (`id`)
		REFERENCES `unit_type` (`id`)
		ON DELETE CASCADE
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- unit
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit`;


CREATE TABLE `unit`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`symbol` VARCHAR(25),
	`unit_type_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `unit_FI_1` (`unit_type_id`),
	CONSTRAINT `unit_FK_1`
		FOREIGN KEY (`unit_type_id`)
		REFERENCES `unit_type` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- unit_i18n
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `unit_i18n`;


CREATE TABLE `unit_i18n`
(
	`id` INTEGER  NOT NULL,
	`culture` VARCHAR(7)  NOT NULL,
	`description` VARCHAR(250),
	PRIMARY KEY (`id`,`culture`),
	CONSTRAINT `unit_i18n_FK_1`
		FOREIGN KEY (`id`)
		REFERENCES `unit` (`id`)
		ON DELETE CASCADE
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- conversion_factor
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `conversion_factor`;


CREATE TABLE `conversion_factor`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`origin_id` INTEGER  NOT NULL,
	`destiny_id` INTEGER  NOT NULL,
	`conversion_factor` DOUBLE,
	PRIMARY KEY (`id`),
	UNIQUE KEY `relation` (`origin_id`, `destiny_id`),
	CONSTRAINT `conversion_factor_FK_1`
		FOREIGN KEY (`origin_id`)
		REFERENCES `unit` (`id`),
	INDEX `conversion_factor_FI_2` (`destiny_id`),
	CONSTRAINT `conversion_factor_FK_2`
		FOREIGN KEY (`destiny_id`)
		REFERENCES `unit` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- feedback_type
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `feedback_type`;


CREATE TABLE `feedback_type`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`global_description` VARCHAR(250),
	`coach_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `feedback_type_FI_1` (`coach_id`),
	CONSTRAINT `feedback_type_FK_1`
		FOREIGN KEY (`coach_id`)
		REFERENCES `user` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- feedback_type_i18n
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `feedback_type_i18n`;


CREATE TABLE `feedback_type_i18n`
(
	`id` INTEGER  NOT NULL,
	`culture` VARCHAR(7)  NOT NULL,
	`description` VARCHAR(250),
	PRIMARY KEY (`id`,`culture`),
	CONSTRAINT `feedback_type_i18n_FK_1`
		FOREIGN KEY (`id`)
		REFERENCES `feedback_type` (`id`)
		ON DELETE CASCADE
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- element_feedback
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `element_feedback`;


CREATE TABLE `element_feedback`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`quantity` DOUBLE,
	`feedback_type_id` INTEGER,
	`unit_id` INTEGER,
	`session_element_id` INTEGER,
	`pending` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `element_feedback_FI_1` (`feedback_type_id`),
	CONSTRAINT `element_feedback_FK_1`
		FOREIGN KEY (`feedback_type_id`)
		REFERENCES `feedback_type` (`id`),
	INDEX `element_feedback_FI_2` (`unit_id`),
	CONSTRAINT `element_feedback_FK_2`
		FOREIGN KEY (`unit_id`)
		REFERENCES `unit` (`id`),
	INDEX `element_feedback_FI_3` (`session_element_id`),
	CONSTRAINT `element_feedback_FK_3`
		FOREIGN KEY (`session_element_id`)
		REFERENCES `session_element` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- feedback
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `feedback`;


CREATE TABLE `feedback`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`quantity` DOUBLE,
	`unit_id` INTEGER,
	`session_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `feedback_FI_1` (`unit_id`),
	CONSTRAINT `feedback_FK_1`
		FOREIGN KEY (`unit_id`)
		REFERENCES `unit` (`id`),
	INDEX `feedback_FI_2` (`session_id`),
	CONSTRAINT `feedback_FK_2`
		FOREIGN KEY (`session_id`)
		REFERENCES `session` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- working_method
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `working_method`;


CREATE TABLE `working_method`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- season
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `season`;


CREATE TABLE `season`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`user_id` INTEGER,
	`theoric_intensity` DOUBLE,
	`theoric_volume` DOUBLE,
	`reported_intensity` DOUBLE,
	`reported_volume` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `season_FI_1` (`user_id`),
	CONSTRAINT `season_FK_1`
		FOREIGN KEY (`user_id`)
		REFERENCES `user` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- macrocycle
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `macrocycle`;


CREATE TABLE `macrocycle`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`season_id` INTEGER,
	`theoric_intensity` DOUBLE,
	`theoric_volume` DOUBLE,
	`reported_intensity` DOUBLE,
	`reported_volume` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `macrocycle_FI_1` (`season_id`),
	CONSTRAINT `macrocycle_FK_1`
		FOREIGN KEY (`season_id`)
		REFERENCES `season` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- mesocycle
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `mesocycle`;


CREATE TABLE `mesocycle`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`macrocycle_id` INTEGER,
	`theoric_intensity` DOUBLE,
	`theoric_volume` DOUBLE,
	`reported_intensity` DOUBLE,
	`reported_volume` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `mesocycle_FI_1` (`macrocycle_id`),
	CONSTRAINT `mesocycle_FK_1`
		FOREIGN KEY (`macrocycle_id`)
		REFERENCES `macrocycle` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- microcycle
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `microcycle`;


CREATE TABLE `microcycle`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`start_at` DATE,
	`last_day_at` DATE,
	`mesocycle_id` INTEGER,
	`theoric_intensity` DOUBLE,
	`theoric_volume` DOUBLE,
	`reported_intensity` DOUBLE,
	`reported_volume` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `microcycle_FI_1` (`mesocycle_id`),
	CONSTRAINT `microcycle_FK_1`
		FOREIGN KEY (`mesocycle_id`)
		REFERENCES `mesocycle` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- session
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `session`;


CREATE TABLE `session`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`date` DATE,
	`morning_session` INTEGER,
	`feedback` VARCHAR(250),
	`microcycle_id` INTEGER,
	`wake_up_hr` DOUBLE,
	`theoric_intensity` DOUBLE,
	`theoric_volume` DOUBLE,
	`reported_intensity` DOUBLE,
	`reported_volume` DOUBLE,
	`l_ccl` DOUBLE,
	`ccl` DOUBLE,
	`ccm` DOUBLE,
	`uam` DOUBLE,
	`m_uam` DOUBLE,
	`lact1` DOUBLE,
	`lact2` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `session_FI_1` (`microcycle_id`),
	CONSTRAINT `session_FK_1`
		FOREIGN KEY (`microcycle_id`)
		REFERENCES `microcycle` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- session_element
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `session_element`;


CREATE TABLE `session_element`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`level` INTEGER,
	`working_method_id` INTEGER,
	`session_id` INTEGER,
	`theoric_intensity` DOUBLE,
	`theoric_volume` DOUBLE,
	`reported_intensity` DOUBLE,
	`reported_volume` DOUBLE,
	PRIMARY KEY (`id`),
	INDEX `session_element_FI_1` (`working_method_id`),
	CONSTRAINT `session_element_FK_1`
		FOREIGN KEY (`working_method_id`)
		REFERENCES `working_method` (`id`),
	INDEX `session_element_FI_2` (`session_id`),
	CONSTRAINT `session_element_FK_2`
		FOREIGN KEY (`session_id`)
		REFERENCES `session` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- picture
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `picture`;


CREATE TABLE `picture`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(255),
	`mime` VARCHAR(255),
	`size` INTEGER,
	`data` LONGBLOB,
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- competition
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `competition`;


CREATE TABLE `competition`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(250),
	`date` DATE,
	`coach_id` INTEGER,
	PRIMARY KEY (`id`),
	INDEX `competition_FI_1` (`coach_id`),
	CONSTRAINT `competition_FK_1`
		FOREIGN KEY (`coach_id`)
		REFERENCES `user` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- competition_competitor
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `competition_competitor`;


CREATE TABLE `competition_competitor`
(
	`competition_id` INTEGER  NOT NULL,
	`competitor_id` INTEGER  NOT NULL,
	`visible` INTEGER,
	PRIMARY KEY (`competition_id`,`competitor_id`),
	CONSTRAINT `competition_competitor_FK_1`
		FOREIGN KEY (`competition_id`)
		REFERENCES `competition` (`id`),
	INDEX `competition_competitor_FI_2` (`competitor_id`),
	CONSTRAINT `competition_competitor_FK_2`
		FOREIGN KEY (`competitor_id`)
		REFERENCES `user` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- user
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `user`;


CREATE TABLE `user`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`nickname` VARCHAR(50),
	`first_name` VARCHAR(100),
	`last_name` VARCHAR(100),
	`created_at` DATETIME,
	`born_at` DATETIME,
	`is_coach` INTEGER,
	`is_athlete` INTEGER,
	`coach_id` INTEGER,
	`picture_id` INTEGER,
	`is_admin` INTEGER,
	`is_male` INTEGER,
	`email` VARCHAR(100),
	`sha1_password` VARCHAR(40),
	`salt` VARCHAR(32),
	`country` VARCHAR(7),
	`language` VARCHAR(7),
	PRIMARY KEY (`id`),
	UNIQUE KEY `user_U_1` (`nickname`),
	UNIQUE KEY `user_U_2` (`email`),
	INDEX `user_FI_1` (`coach_id`),
	CONSTRAINT `user_FK_1`
		FOREIGN KEY (`coach_id`)
		REFERENCES `user` (`id`),
	INDEX `user_FI_2` (`picture_id`),
	CONSTRAINT `user_FK_2`
		FOREIGN KEY (`picture_id`)
		REFERENCES `picture` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- article
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `article`;


CREATE TABLE `article`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`author_id` INTEGER,
	`created_at` DATETIME,
	`updated_at` DATETIME,
	PRIMARY KEY (`id`),
	INDEX `article_FI_1` (`author_id`),
	CONSTRAINT `article_FK_1`
		FOREIGN KEY (`author_id`)
		REFERENCES `user` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- article_i18n
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `article_i18n`;


CREATE TABLE `article_i18n`
(
	`id` INTEGER  NOT NULL,
	`culture` VARCHAR(7)  NOT NULL,
	`title` VARCHAR(255),
	`text` TEXT,
	PRIMARY KEY (`id`,`culture`),
	CONSTRAINT `article_i18n_FK_1`
		FOREIGN KEY (`id`)
		REFERENCES `article` (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- category
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `category`;


CREATE TABLE `category`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(100),
	`start_at` DATE,
	`end_at` DATE,
	`male` INTEGER,
	`event_id` INTEGER,
	`circuit_id` INTEGER,
	`price_id` INTEGER,
	`no_competitive` INTEGER,
	PRIMARY KEY (`id`),
	KEY `category_FI_1`(`event_id`),
	KEY `category_FI_2`(`circuit_id`),
	KEY `category_FI_3`(`price_id`),
	CONSTRAINT `category_FK_1`
		FOREIGN KEY (`event_id`)
		REFERENCES `event` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `category_FK_2`
		FOREIGN KEY (`circuit_id`)
		REFERENCES `circuit` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `category_FK_3`
		FOREIGN KEY (`price_id`)
		REFERENCES `price` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- circuit
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `circuit`;


CREATE TABLE `circuit`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(100),
	`distance` DOUBLE,
	`event_id` INTEGER,
	`first_number` INTEGER,
	`last_number` INTEGER,
	PRIMARY KEY (`id`),
	KEY `circuit_FI_1`(`event_id`),
	CONSTRAINT `circuit_FK_1`
		FOREIGN KEY (`event_id`)
		REFERENCES `event` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- event
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `event`;


CREATE TABLE `event`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(100),
	`celebrated_at` DATE,
	`end_inscription_at` DATE,
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- runner
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `runner`;


CREATE TABLE `runner`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(100)  NOT NULL,
	`surname` VARCHAR(250)  NOT NULL,
	`nif` VARCHAR(13),
	`email` VARCHAR(255),
	`address` VARCHAR(255),
	`postal_code` VARCHAR(10),
	`city` VARCHAR(255),
	`region` VARCHAR(100),
	`country` VARCHAR(100),
	`born_at` DATE  NOT NULL,
	`male` INTEGER,
	`club` VARCHAR(100),
	`size_id` INTEGER,
	`federated` INTEGER,
	`licence_number` VARCHAR(20),
	`sport` VARCHAR(100),
	`telephone` VARCHAR(12),
	`no_competitive` INTEGER,
	`price` DOUBLE,
	`inscription_id` INTEGER,
	`category_id` INTEGER,
	`number` INTEGER  NOT NULL,
	`created_at` DATE,
	PRIMARY KEY (`id`),
	UNIQUE KEY `nif-number` (`inscription_id`, `number`),
	KEY `runner_FI_1`(`size_id`),
	KEY `runner_FI_2`(`inscription_id`),
	KEY `runner_FI_3`(`category_id`),
	CONSTRAINT `runner_FK_1`
		FOREIGN KEY (`size_id`)
		REFERENCES `size` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `runner_FK_2`
		FOREIGN KEY (`inscription_id`)
		REFERENCES `inscription` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT,
	CONSTRAINT `runner_FK_3`
		FOREIGN KEY (`category_id`)
		REFERENCES `category` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- inscription
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `inscription`;


CREATE TABLE `inscription`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`name` VARCHAR(100)  NOT NULL,
	`surname` VARCHAR(250)  NOT NULL,
	`nif` VARCHAR(13),
	`email` VARCHAR(255)  NOT NULL,
	`address` VARCHAR(255),
	`postal_code` VARCHAR(10),
	`city` VARCHAR(255),
	`region` VARCHAR(100),
	`country` VARCHAR(100),
	`club` VARCHAR(100),
	`price` DOUBLE,
	`payed` INTEGER,
	`telephone` VARCHAR(12)  NOT NULL,
	`created_at` DATE,
	`event_id` INTEGER,
	PRIMARY KEY (`id`),
	UNIQUE KEY `nif-event` (`nif`, `event_id`),
	INDEX `inscription_FI_1` (`event_id`),
	CONSTRAINT `inscription_FK_1`
		FOREIGN KEY (`event_id`)
		REFERENCES `event` (`id`)
		ON UPDATE RESTRICT
		ON DELETE RESTRICT
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- price
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `price`;


CREATE TABLE `price`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`amount1` DOUBLE,
	`init1_at` DATE,
	`amount2` DOUBLE,
	`init2_at` DATE,
	PRIMARY KEY (`id`)
)Type=InnoDB;

#-----------------------------------------------------------------------------
#-- size
#-----------------------------------------------------------------------------

DROP TABLE IF EXISTS `size`;


CREATE TABLE `size`
(
	`id` INTEGER  NOT NULL AUTO_INCREMENT,
	`description` VARCHAR(100),
	`summary` VARCHAR(5),
	PRIMARY KEY (`id`)
)Type=InnoDB;

# This restores the fkey checks, after having unset them earlier
SET FOREIGN_KEY_CHECKS = 1;
